## SCENARIO 4: One input and output groups; multiple other entities; active scenarios; each type of invalid scenario

### INPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Invalidity Types | ;;

####

#### GROUP 2: Input Fields

# | Group | Field
--- | --- | ---
1 | Input Group 1 | Input Field 1-1
2 | Input Group 1 | Input Field 1-2

####

#### GROUP 3: Output Fields

# | Group | Field
--- | --- | ---
1 | Output Group 1 | Output Field 1-1
2 | Output Group 1 | Output Field 1-2

####

#### GROUP 4: Scenario

# | Scenario | Active Y/N
--- | --- | ---
1 | E=A | Y
2 | E>A | Y
3 | E | Y

####

#### GROUP 5: Input Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | E=A | Input Group 1 | S1R1 IV-11;;R1 IV-12
2 | E>A | Input Group 1 | S2R1 IV-11;;R1 IV-12
3 | E | Input Group 1 | S3R1 IV-11;;R1 IV-12

####

#### GROUP 6: Expected Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | E=A | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | E=A | Output Group 1 | S1R2 EV-11;;R2 EV-12
3 | E>A | Output Group 1 | S2R1 EV-11;;R1 EV-12
4 | E>A | Output Group 1 | S2R2 EV-21;;R1 EV-22
5 | E | Output Group 1 | S3R1 EV-11;;R1 EV-12

####

#### GROUP 7: Actual Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | E=A | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | E=A | Output Group 1 | S1R2 EV-11;;R2 EV-12XXX
3 | E>A | Output Group 1 | S2R1 EV-11;;R1 EV-12
4 | E | Output Group 1 | S3R1 EV-21;;R2 EV-12
5 | E | Output Group 1 | S3R2 EV-21;;R2 EV-22

####

### OUTPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Invalidity Types | ;;

#### 0 failed of 1: SUCCESS

#### GROUP 2: Input Fields

# | Group | Field
--- | --- | ---
1 | Input Group 1 | Input Field 1-1
2 | Input Group 1 | Input Field 1-2

#### 0 failed of 2: SUCCESS

#### GROUP 3: Output Fields

# | Group | Field
--- | --- | ---
1 | Output Group 1 | Output Field 1-1
2 | Output Group 1 | Output Field 1-2

#### 0 failed of 2: SUCCESS

#### GROUP 4: Input Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | E=A | Input Group 1 | S1R1 IV-11;;R1 IV-12
2 | E>A | Input Group 1 | S2R1 IV-11;;R1 IV-12
3 | E | Input Group 1 | S3R1 IV-11;;R1 IV-12

#### 0 failed of 3: SUCCESS

#### GROUP 5: Expected Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | E=A | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | E=A | Output Group 1 | S1R2 EV-11;;R2 EV-12
3 | E>A | Output Group 1 | S2R1 EV-11;;R1 EV-12
4 | E>A | Output Group 1 | S2R2 EV-21;;R1 EV-22
5 | E | Output Group 1 | S3R1 EV-11;;R1 EV-12

#### 0 failed of 5: SUCCESS

#### GROUP 6: Actual Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | E=A | Output Group 1 | S1R1 EV-11;;R1 EV-12
2 | E=A | Output Group 1 | S1R2 EV-11;;R2 EV-12XXX
3 | E>A | Output Group 1 | S2R1 EV-11;;R1 EV-12
4 | E | Output Group 1 | S3R1 EV-21;;R2 EV-12
5 | E | Output Group 1 | S3R2 EV-21;;R2 EV-22

#### 0 failed of 5: SUCCESS

## 0 failed of 6: SUCCESS